@@ -14,13 +14,17 @@
   +----------------------------------------------------------------------+
 */
 
-/* $ Id: $ */ 
+/* $ Id: $ */
 
 #ifndef PHP_MEMCACHED_H
 #define PHP_MEMCACHED_H
 
 #include <libmemcached/memcached.h>
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 extern zend_module_entry memcached_module_entry;
 #define phpext_memcached_ptr &memcached_module_entry
 
@@ -30,25 +34,64 @@ extern zend_module_entry memcached_module_entry;
 #define PHP_MEMCACHED_API
 #endif
 
+/****************************************
+  Structures and definitions
+****************************************/
+enum memcached_serializer {
+	SERIALIZER_PHP = 1,
+	SERIALIZER_IGBINARY = 2,
+	SERIALIZER_JSON = 3,
+	SERIALIZER_JSON_ARRAY = 4,
+};
+#ifdef HAVE_MEMCACHED_IGBINARY
+#define SERIALIZER_DEFAULT SERIALIZER_IGBINARY
+#define SERIALIZER_DEFAULT_NAME "igbinary"
+#else
+#define SERIALIZER_DEFAULT SERIALIZER_PHP
+#define SERIALIZER_DEFAULT_NAME "php"
+#endif /* HAVE_MEMCACHED_IGBINARY */
+
+#if LIBMEMCACHED_WITH_SASL_SUPPORT
+# if defined(HAVE_SASL_SASL_H)
+#  include <sasl/sasl.h>
+#  define HAVE_MEMCACHED_SASL 1
+# endif
+#endif
+
 ZEND_BEGIN_MODULE_GLOBALS(php_memcached)
-	memcached_return rescode;
-#if HAVE_MEMCACHED_SESSION
-	short sess_locked:1;
+#ifdef HAVE_MEMCACHED_SESSION
+	zend_bool sess_locking_enabled;
+	long  sess_lock_wait;
+	char* sess_prefix;
+	zend_bool sess_locked;
 	char* sess_lock_key;
 	int   sess_lock_key_len;
 #endif
-	int   serializer;
+	char *serializer_name;
+	enum memcached_serializer serializer;
+
+	char *compression_type;
+	int   compression_type_real;
+	int   compression_threshold;
+
+	double compression_factor;
+#if HAVE_MEMCACHED_SASL
+	bool use_sasl;
+#endif
+	zend_bool sess_binary_enabled;
 ZEND_END_MODULE_GLOBALS(php_memcached)
 
 PHP_MEMCACHED_API zend_class_entry *php_memc_get_ce(void);
 PHP_MEMCACHED_API zend_class_entry *php_memc_get_exception(void);
 PHP_MEMCACHED_API zend_class_entry *php_memc_get_exception_base(int root TSRMLS_DC);
 
+PHP_RINIT_FUNCTION(memcached);
+PHP_RSHUTDOWN_FUNCTION(memcached);
 PHP_MINIT_FUNCTION(memcached);
 PHP_MSHUTDOWN_FUNCTION(memcached);
 PHP_MINFO_FUNCTION(memcached);
 
-#define PHP_MEMCACHED_VERSION "1.0.2"
+#define PHP_MEMCACHED_VERSION "2.0.1"
 
 #ifdef ZTS
 #define MEMC_G(v) TSRMG(php_memcached_globals_id, zend_php_memcached_globals *, v)
@@ -56,24 +99,15 @@ PHP_MINFO_FUNCTION(memcached);
 #define MEMC_G(v) (php_memcached_globals.v)
 #endif
 
-/* session handler struct */
-#if HAVE_MEMCACHED_SESSION
-#include "ext/session/php_session.h"
+typedef struct {
+	memcached_st *memc_sess;
+	zend_bool is_persisent;
+} memcached_sess;
 
-extern ps_module ps_mod_memcached;
-#define ps_memcached_ptr &ps_mod_memcached
-
-PS_FUNCS(memcached);
-#endif
-
-/* json serializer */
-#if (PHP_MAJOR_VERSION > 5) || (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION > 2) || (PHP_MAJOR_VERSION ==5 && PHP_MINOR_VERSION == 2 && PHP_RELEASE_VERSION > 9)
-#define HAVE_JSON_API 1
-#endif
+int php_memc_sess_list_entry(void);
 
 #endif /* PHP_MEMCACHED_H */
 
-
 /*
  * Local variables:
  * tab-width: 4
